* headers.mk: update distributed headers.
* tests/unit_test/mln_io_raw_all.cc,
* tests/unit_test/mln_io_raw_load.cc,
* tests/unit_test/mln_io_raw_save.cc,
* tests/io/raw/raw.cc,
* tests/io/raw/Makefile.am,
* tests/io/raw/pbm.cc,
* mln/io/raw/all.hh,
* mln/io/raw/load.hh,
* mln/io/raw/save.hh: move to...
* tests/unit_test/mln_io_dump_all,
* tests/unit_test/mln_io_dump_load,
* tests/unit_test/mln_io_dump_save,
* tests/io/dump/Makefile.am,
* tests/io/dump/dump.cc,
* mln/io/dump/all.hh,
* mln/io/dump/load.hh,
* mln/io/dump/save.hh: ... here.
* mln/io/all.hh
* mln/io/essential.hh: update includes.
* tests/unit_test/Makefile.am: update unit test list.
---
milena/ChangeLog | 30 ++++++++++
milena/headers.mk | 6 +-
milena/mln/io/all.hh | 1 +
milena/mln/io/{raw => dump}/all.hh | 18 +++---
milena/mln/io/{raw => dump}/load.hh | 18 +++---
milena/mln/io/{raw => dump}/save.hh | 18 +++---
milena/mln/io/essential.hh | 14 ++---
milena/tests/io/{raw => dump}/Makefile.am | 4 +-
milena/tests/io/{raw/raw.cc => dump/dump.cc} | 20 +++---
milena/tests/io/raw/pbm.cc | 62 --------------------
milena/tests/unit_test/Makefile.am | 12 ++--
.../{mln_io_raw_all.cc => mln_io_dump_all.cc} | 6 +-
.../{mln_io_raw_load.cc => mln_io_dump_load.cc} | 6 +-
.../{mln_io_raw_save.cc => mln_io_dump_save.cc} | 6 +-
14 files changed, 93 insertions(+), 128 deletions(-)
rename milena/mln/io/{raw => dump}/all.hh (82%)
rename milena/mln/io/{raw => dump}/load.hh (91%)
rename milena/mln/io/{raw => dump}/save.hh (90%)
rename milena/tests/io/{raw => dump}/Makefile.am (84%)
rename milena/tests/io/{raw/raw.cc => dump/dump.cc} (87%)
delete mode 100644 milena/tests/io/raw/pbm.cc
rename milena/tests/unit_test/{mln_io_raw_all.cc => mln_io_dump_all.cc} (60%)
rename milena/tests/unit_test/{mln_io_raw_load.cc => mln_io_dump_load.cc} (60%)
rename milena/tests/unit_test/{mln_io_raw_save.cc => mln_io_dump_save.cc} (60%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 5669206..dd76502 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,35 @@
2009-02-03 Guillaume Lazzara <z(a)lrde.epita.fr>
+ Rename io::raw as io::dump.
+
+ * headers.mk: update distributed headers.
+
+ * tests/unit_test/mln_io_raw_all.cc,
+ * tests/unit_test/mln_io_raw_load.cc,
+ * tests/unit_test/mln_io_raw_save.cc,
+ * tests/io/raw/raw.cc,
+ * tests/io/raw/Makefile.am,
+ * tests/io/raw/pbm.cc,
+ * mln/io/raw/all.hh,
+ * mln/io/raw/load.hh,
+ * mln/io/raw/save.hh: move to...
+
+ * tests/unit_test/mln_io_dump_all,
+ * tests/unit_test/mln_io_dump_load,
+ * tests/unit_test/mln_io_dump_save,
+ * tests/io/dump/Makefile.am,
+ * tests/io/dump/dump.cc,
+ * mln/io/dump/all.hh,
+ * mln/io/dump/load.hh,
+ * mln/io/dump/save.hh: ... here.
+
+ * mln/io/all.hh
+ * mln/io/essential.hh: update includes.
+
+ * tests/unit_test/Makefile.am: update unit test list.
+
+2009-02-03 Guillaume Lazzara <z(a)lrde.epita.fr>
+
Update new version of ICP.
* mln/registration/icp2.hh: Make it work and make it more generic.
diff --git a/milena/headers.mk b/milena/headers.mk
index 48ce0e0..26b1b7e 100644
--- a/milena/headers.mk
+++ b/milena/headers.mk
@@ -997,13 +997,13 @@ mln/io/ppm/save.hh \
mln/io/pfm/load.hh \
mln/io/pfm/all.hh \
mln/io/pfm/save.hh \
-mln/io/raw/load.hh \
-mln/io/raw/all.hh \
-mln/io/raw/save.hh \
mln/io/cloud/load.hh \
mln/io/cloud/all.hh \
mln/io/cloud/save.hh \
mln/io/all.hh \
+mln/io/dump/load.hh \
+mln/io/dump/all.hh \
+mln/io/dump/save.hh \
mln/io/pbm/load.hh \
mln/io/pbm/all.hh \
mln/io/pbm/save.hh \
diff --git a/milena/mln/io/all.hh b/milena/mln/io/all.hh
index 777ffb7..da9ddb8 100644
--- a/milena/mln/io/all.hh
+++ b/milena/mln/io/all.hh
@@ -47,6 +47,7 @@ namespace mln
}
# include <mln/io/cloud/all.hh>
+# include <mln/io/dump/all.hh>
# include <mln/io/pbm/all.hh>
# include <mln/io/pfm/all.hh>
# include <mln/io/pgm/all.hh>
diff --git a/milena/mln/io/essential.hh b/milena/mln/io/essential.hh
index d55f114..2b5199e 100644
--- a/milena/mln/io/essential.hh
+++ b/milena/mln/io/essential.hh
@@ -1,4 +1,5 @@
-// Copyright (C) 2008 EPITA Research and Development Laboratory
+// Copyright (C) 2008, 2009 EPITA Research and Development Laboratory
+// (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -28,18 +29,13 @@
#ifndef MLN_IO_ESSENTIAL_HH_
# define MLN_IO_ESSENTIAL_HH_
-/*! \file mln/io/essential.hh
- *
- * \brief File that includes the most useful io routines.
- *
- */
+/// \file mln/io/essential.hh
+///
+/// File that includes the most useful io routines.
# include <mln/io/pbm/all.hh>
-# include <mln/io/pfm/all.hh>
# include <mln/io/pgm/all.hh>
-# include <mln/io/pnm/all.hh>
# include <mln/io/ppm/all.hh>
-# include <mln/io/txt/all.hh>
#endif // !MLN_IO_ESSENTIAL_HH_
diff --git a/milena/tests/io/raw/Makefile.am b/milena/tests/io/dump/Makefile.am
similarity index 84%
rename from milena/tests/io/raw/Makefile.am
rename to milena/tests/io/dump/Makefile.am
index 2d3d1c0..36be121 100644
--- a/milena/tests/io/raw/Makefile.am
+++ b/milena/tests/io/dump/Makefile.am
@@ -3,8 +3,8 @@
include $(top_srcdir)/milena/tests/tests.mk
check_PROGRAMS = \
- raw
+ dump
-raw_SOURCES = raw.cc
+dump_SOURCES = dump.cc
TESTS = $(check_PROGRAMS)
diff --git a/milena/tests/io/raw/pbm.cc b/milena/tests/io/raw/pbm.cc
deleted file mode 100644
index 3ccc040..0000000
--- a/milena/tests/io/raw/pbm.cc
+++ /dev/null
@@ -1,62 +0,0 @@
-// Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
-//
-// This file is part of the Olena Library. This library is free
-// software; you can redistribute it and/or modify it under the terms
-// of the GNU General Public License version 2 as published by the
-// Free Software Foundation.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this library; see the file COPYING. If not, write to
-// the Free Software Foundation, 51 Franklin Street, Fifth Floor,
-// Boston, MA 02111-1307, USA.
-//
-// As a special exception, you may use this file as part of a free
-// software library without restriction. Specifically, if other files
-// instantiate templates or use macros or inline functions from this
-// file, or you compile this file and link it with other files to
-// produce an executable, this file does not by itself cause the
-// resulting executable to be covered by the GNU General Public
-// License. This exception does not however invalidate any other
-// reasons why the executable file might be covered by the GNU General
-// Public License.
-
-/// \file tests/io/raw/raw.cc
-///
-/// Test on mln::io::raw::.
-
-#include <mln/core/image/image2d.hh>
-#include <mln/io/pbm/load.hh>
-#include <mln/io/raw/load.hh>
-#include <mln/io/raw/save.hh>
-
-#include <mln/level/compare.hh>
-
-#include "tests/data.hh"
-
-
-int main()
-{
- using namespace mln;
-
- image2d<bool> pic = io::pbm::load(MLN_IMG_DIR "/picasso.pbm");
- io::raw::save(pic, "pic.raw");
-// image2d<bool> pic2 = io::raw::load("pic.raw");
-
-// mln_assertion(pic == pic2);
-}
-
-
-// sample binary image to test with xv, imview, and display
-// to bring into the fore the binary image bug with raw raw.
-
-// | | | | -
-// | | - - -
-// | - - - -
-// - - - - -
-// - - - - -
-// - - - - -
diff --git a/milena/tests/unit_test/Makefile.am b/milena/tests/unit_test/Makefile.am
index 8c4e274..46e968c 100644
--- a/milena/tests/unit_test/Makefile.am
+++ b/milena/tests/unit_test/Makefile.am
@@ -963,13 +963,13 @@ mln_io_ppm_save \
mln_io_pfm_load \
mln_io_pfm_all \
mln_io_pfm_save \
-mln_io_raw_load \
-mln_io_raw_all \
-mln_io_raw_save \
mln_io_cloud_load \
mln_io_cloud_all \
mln_io_cloud_save \
mln_io_all \
+mln_io_dump_load \
+mln_io_dump_all \
+mln_io_dump_save \
mln_io_pbm_load \
mln_io_pbm_all \
mln_io_pbm_save \
@@ -2005,13 +2005,13 @@ mln_io_ppm_save_SOURCES = mln_io_ppm_save.cc
mln_io_pfm_load_SOURCES = mln_io_pfm_load.cc
mln_io_pfm_all_SOURCES = mln_io_pfm_all.cc
mln_io_pfm_save_SOURCES = mln_io_pfm_save.cc
-mln_io_raw_load_SOURCES = mln_io_raw_load.cc
-mln_io_raw_all_SOURCES = mln_io_raw_all.cc
-mln_io_raw_save_SOURCES = mln_io_raw_save.cc
mln_io_cloud_load_SOURCES = mln_io_cloud_load.cc
mln_io_cloud_all_SOURCES = mln_io_cloud_all.cc
mln_io_cloud_save_SOURCES = mln_io_cloud_save.cc
mln_io_all_SOURCES = mln_io_all.cc
+mln_io_dump_load_SOURCES = mln_io_dump_load.cc
+mln_io_dump_all_SOURCES = mln_io_dump_all.cc
+mln_io_dump_save_SOURCES = mln_io_dump_save.cc
mln_io_pbm_load_SOURCES = mln_io_pbm_load.cc
mln_io_pbm_all_SOURCES = mln_io_pbm_all.cc
mln_io_pbm_save_SOURCES = mln_io_pbm_save.cc
diff --git a/milena/tests/unit_test/mln_io_raw_all.cc
b/milena/tests/unit_test/mln_io_dump_all.cc
similarity index 60%
rename from milena/tests/unit_test/mln_io_raw_all.cc
rename to milena/tests/unit_test/mln_io_dump_all.cc
index 40875ba..0b1f553 100644
--- a/milena/tests/unit_test/mln_io_raw_all.cc
+++ b/milena/tests/unit_test/mln_io_dump_all.cc
@@ -1,9 +1,9 @@
-// Unit test for mln/io/raw/all.hh.
+// Unit test for mln/io/dump/all.hh.
// Generated by ./build_unit_test.sh, do not modify.
// Include the file twice, so we detect missing inclusion guards.
-#include <mln/io/raw/all.hh>
-#include <mln/io/raw/all.hh>
+#include <mln/io/dump/all.hh>
+#include <mln/io/dump/all.hh>
int main()
{
diff --git a/milena/tests/unit_test/mln_io_raw_load.cc
b/milena/tests/unit_test/mln_io_dump_load.cc
similarity index 60%
rename from milena/tests/unit_test/mln_io_raw_load.cc
rename to milena/tests/unit_test/mln_io_dump_load.cc
index 11f9ba6..105868f 100644
--- a/milena/tests/unit_test/mln_io_raw_load.cc
+++ b/milena/tests/unit_test/mln_io_dump_load.cc
@@ -1,9 +1,9 @@
-// Unit test for mln/io/raw/load.hh.
+// Unit test for mln/io/dump/load.hh.
// Generated by ./build_unit_test.sh, do not modify.
// Include the file twice, so we detect missing inclusion guards.
-#include <mln/io/raw/load.hh>
-#include <mln/io/raw/load.hh>
+#include <mln/io/dump/load.hh>
+#include <mln/io/dump/load.hh>
int main()
{
diff --git a/milena/tests/unit_test/mln_io_raw_save.cc
b/milena/tests/unit_test/mln_io_dump_save.cc
similarity index 60%
rename from milena/tests/unit_test/mln_io_raw_save.cc
rename to milena/tests/unit_test/mln_io_dump_save.cc
index 3ead995..05baca1 100644
--- a/milena/tests/unit_test/mln_io_raw_save.cc
+++ b/milena/tests/unit_test/mln_io_dump_save.cc
@@ -1,9 +1,9 @@
-// Unit test for mln/io/raw/save.hh.
+// Unit test for mln/io/dump/save.hh.
// Generated by ./build_unit_test.sh, do not modify.
// Include the file twice, so we detect missing inclusion guards.
-#include <mln/io/raw/save.hh>
-#include <mln/io/raw/save.hh>
+#include <mln/io/dump/save.hh>
+#include <mln/io/dump/save.hh>
int main()
{
diff --git a/milena/mln/io/raw/all.hh b/milena/mln/io/dump/all.hh
similarity index 82%
rename from milena/mln/io/raw/all.hh
rename to milena/mln/io/dump/all.hh
index 32d34d7..97fc972 100644
--- a/milena/mln/io/raw/all.hh
+++ b/milena/mln/io/dump/all.hh
@@ -25,12 +25,12 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_IO_RAW_ALL_HH
-# define MLN_IO_RAW_ALL_HH
+#ifndef MLN_IO_DUMP_ALL_HH
+# define MLN_IO_DUMP_ALL_HH
-/// \file mln/io/raw/all.hh
+/// \file mln/io/dump/all.hh
///
/// File that includes all raw io materials.
namespace mln
@@ -38,13 +38,13 @@ namespace mln
namespace io
{
- /// Namespace of raw input/output handling.
- namespace raw {}
+ /// Namespace of dump input/output handling.
+ namespace dump {}
}
}
-# include <mln/io/raw/load.hh>
-# include <mln/io/raw/save.hh>
+# include <mln/io/dump/load.hh>
+# include <mln/io/dump/save.hh>
-#endif // ! MLN_IO_RAW_ALL_HH
+#endif // ! MLN_IO_DUMP_ALL_HH
@@ -25,12 +25,12 @@
///
-/// File that includes all raw io materials.
+/// File that includes all dump io materials.
namespace mln
diff --git a/milena/mln/io/raw/load.hh b/milena/mln/io/dump/load.hh
similarity index 91%
rename from milena/mln/io/raw/load.hh
rename to milena/mln/io/dump/load.hh
index eb1d789..7bbce9e 100644
--- a/milena/mln/io/raw/load.hh
+++ b/milena/mln/io/dump/load.hh
@@ -25,10 +25,10 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_IO_RAW_LOAD_HH
-# define MLN_IO_RAW_LOAD_HH
+#ifndef MLN_IO_DUMP_LOAD_HH
+# define MLN_IO_DUMP_LOAD_HH
-/// \file mln/io/raw/load.hh
+/// \file mln/io/dump/load.hh
///
/// Load a Milena image dumped into a file.
@@ -47,7 +47,7 @@ namespace mln
namespace io
{
- namespace raw
+ namespace dump
{
/// Load a Milena image by dumped into a file.
@@ -110,14 +110,14 @@ namespace mln
}
- } // end of namespace mln::io::raw::internal
+ } // end of namespace mln::io::dump::internal
template <typename I>
void load(Image<I>& ima, const std::string& filename)
{
- trace::entering("mln::io::raw::load");
+ trace::entering("mln::io::dump::load");
std::ifstream file(filename.c_str());
if (! file)
@@ -129,16 +129,16 @@ namespace mln
internal::load_header(ima, file);
internal::load_data(ima, file);
- trace::exiting("mln::io::raw::load");
+ trace::exiting("mln::io::dump::load");
}
# endif // ! MLN_INCLUDE_ONLY
- } // end of namespace mln::io::raw
+ } // end of namespace mln::io::dump
} // end of namespace mln::io
} // end of namespace mln
-#endif // ! MLN_IO_RAW_LOAD_HH
+#endif // ! MLN_IO_DUMP_LOAD_HH
diff --git a/milena/mln/io/raw/save.hh b/milena/mln/io/dump/save.hh
similarity index 90%
rename from milena/mln/io/raw/save.hh
rename to milena/mln/io/dump/save.hh
index 06c1f7d..a489a20 100644
--- a/milena/mln/io/raw/save.hh
+++ b/milena/mln/io/dump/save.hh
@@ -25,10 +25,10 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_IO_RAW_SAVE_HH
-# define MLN_IO_RAW_SAVE_HH
+#ifndef MLN_IO_DUMP_SAVE_HH
+# define MLN_IO_DUMP_SAVE_HH
-/// \file mln/io/raw/save.hh
+/// \file mln/io/dump/save.hh
///
/// Save a Milena image by dumping its data to a file.
/// \todo handle endianness.
@@ -47,7 +47,7 @@ namespace mln
namespace io
{
- namespace raw
+ namespace dump
{
/// Save a Milena image by dumping its data to a file.
@@ -94,13 +94,13 @@ namespace mln
}
}
- } // end of namespace mln::io::raw::internal
+ } // end of namespace mln::io::dump::internal
template <typename I>
void save(const Image<I>& ima_, const std::string& filename)
{
- trace::entering("mln::io::raw::save");
+ trace::entering("mln::io::dump::save");
const I& ima = exact(ima_);
@@ -114,16 +114,16 @@ namespace mln
internal::save_header(ima, file);
internal::save_data(ima, file);
- trace::exiting("mln::io::raw::save");
+ trace::exiting("mln::io::dump::save");
}
# endif // ! MLN_INCLUDE_ONLY
- } // end of namespace mln::io::raw
+ } // end of namespace mln::io::dump
} // end of namespace mln::io
} // end of namespace mln
-#endif // ! MLN_IO_RAW_SAVE_HH
+#endif // ! MLN_IO_DUMP_SAVE_HH
diff --git a/milena/tests/io/raw/raw.cc b/milena/tests/io/dump/dump.cc
similarity index 87%
rename from milena/tests/io/raw/raw.cc
rename to milena/tests/io/dump/dump.cc
index 193b125..6099bc9 100644
--- a/milena/tests/io/raw/raw.cc
+++ b/milena/tests/io/dump/dump.cc
@@ -25,13 +25,13 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/// \file tests/io/raw/raw.cc
+/// \file tests/io/dump/dump.cc
///
/// Test on mln::io::raw::*.
#include <mln/core/image/image2d.hh>
-#include <mln/io/raw/load.hh>
-#include <mln/io/raw/save.hh>
+#include <mln/io/dump/load.hh>
+#include <mln/io/dump/save.hh>
#include <mln/level/compare.hh>
@@ -52,10 +52,10 @@ int main()
1, 0 };
image2d<bool> pic = make::image2d(data);
- io::raw::save(pic, "pic.raw");
+ io::dump::save(pic, "pic.dump");
image2d<bool> pic2;
- io::raw::load(pic2, "pic.raw");
+ io::dump::load(pic2, "pic.dump");
mln_assertion(pic.domain() == pic2.domain());
mln_assertion(pic == pic2);
@@ -66,10 +66,10 @@ int main()
value::int_u8 data[4] = { 5, 1,
1, 9 };
image2d<value::int_u8> pic = make::image2d(data);
- io::raw::save(pic, "pic.raw");
+ io::dump::save(pic, "pic.dump");
image2d<value::int_u8> pic2;
- io::raw::load(pic2, "pic.raw");
+ io::dump::load(pic2, "pic.dump");
mln_assertion(pic.domain() == pic2.domain());
mln_assertion(pic == pic2);
@@ -81,10 +81,10 @@ int main()
value::rgb8 data[4] = { rgb8(2,4,5), rgb8(1,23,255),
rgb8(64,41,150), rgb8(23,53,49) };
image2d<value::rgb8> pic = make::image2d(data);
- io::raw::save(pic, "pic.raw");
+ io::dump::save(pic, "pic.dump");
image2d<value::rgb8> pic2;
- io::raw::load(pic2, "pic.raw");
+ io::dump::load(pic2, "pic.dump");
mln_assertion(pic.domain() == pic2.domain());
mln_assertion(pic == pic2);
@@ -25,13 +25,13 @@
///
-/// Test on mln::io::raw::*.
+/// Test on mln::io::dump::*.
#include <mln/core/image/image2d.hh>
--
1.5.6.5